==> cratedb_toolkit-0.0.15.tar.gz: cratedb_toolkit-0.0.15/doc/index.md <==
(index)=
# CrateDB Toolkit

[![CI][badge-tests]][project-tests]
[![Coverage Status][badge-coverage]][project-codecov]
[![Documentation][badge-documentation]][project-documentation]
[![License][badge-license]][project-license]
[![Downloads per month][badge-downloads-per-month]][project-downloads]

[![Supported Python versions][badge-python-versions]][project-pypi]
[![Status][badge-status]][project-pypi]
[![Package version][badge-package-version]][project-pypi]

```{include} readme.md
:start-line: 12
```


```{toctree}
:maxdepth: 3
:caption: Documentation
:hidden:

install
datasets
adapter/index
io/index
retention
Cluster Flight Recorder (CFR) <cfr/index>
Ad Hoc Diagnosis (WTF) <wtf/index>
```

```{toctree}
:maxdepth: 1
:caption: Workbench
:hidden:

changes
backlog
sandbox
release
```


[cratedb-toolkit]: https://cratedb-toolkit.readthedocs.io/
[influxio]: https://influxio.readthedocs.io/

[badge-coverage]: https://codecov.io/gh/crate-workbench/cratedb-toolkit/branch/main/graph/badge.svg
[badge-documentation]: https://img.shields.io/readthedocs/cratedb-toolkit
[badge-downloads-per-month]: https://pepy.tech/badge/cratedb-toolkit/month
[badge-license]: https://img.shields.io/github/license/crate-workbench/cratedb-toolkit.svg
[badge-package-version]: https://img.shields.io/pypi/v/cratedb-toolkit.svg
[badge-python-versions]: https://img.shields.io/pypi/pyversions/cratedb-toolkit.svg
[badge-status]: https://img.shields.io/pypi/status/cratedb-toolkit.svg
[badge-tests]: https://github.com/crate-workbench/cratedb-toolkit/actions/workflows/main.yml/badge.svg
[project-codecov]: https://codecov.io/gh/crate-workbench/cratedb-toolkit
[project-documentation]: https://cratedb-toolkit.readthedocs.io/
[project-downloads]: https://pepy.tech/project/cratedb-toolkit/
[project-license]: https://github.com/crate-workbench/cratedb-toolkit/blob/main/LICENSE
[project-pypi]: https://pypi.org/project/cratedb-toolkit
[project-tests]: https://github.com/crate-workbench/cratedb-toolkit/actions/workflows/main.yml

==> cratedb_toolkit-0.0.20.tar.gz: cratedb_toolkit-0.0.20/doc/index.md <==
(index)=
# CrateDB Toolkit

[![CI][badge-tests]][project-tests]
[![Coverage Status][badge-coverage]][project-codecov]
[![Documentation][badge-documentation]][project-documentation]
[![License][badge-license]][project-license]
[![Downloads per month][badge-downloads-per-month]][project-downloads]

[![Supported Python versions][badge-python-versions]][project-pypi]
[![Status][badge-status]][project-pypi]
[![Package version][badge-package-version]][project-pypi]

```{include} readme.md
:start-line: 12
```


```{toctree}
:maxdepth: 3
:caption: Documentation
:hidden:

install
datasets
adapter/index
io/index
retention
Cluster Flight Recorder (CFR) <cfr/index>
Ad Hoc Diagnosis (WTF) <wtf/index>
```

```{toctree}
:maxdepth: 1
:caption: Workbench
:hidden:

changes
backlog
sandbox
release
```


[cratedb-toolkit]: https://cratedb-toolkit.readthedocs.io/
[influxio]: https://influxio.readthedocs.io/

[badge-coverage]: https://codecov.io/gh/crate/cratedb-toolkit/branch/main/graph/badge.svg
[badge-documentation]: https://img.shields.io/readthedocs/cratedb-toolkit
[badge-downloads-per-month]: https://pepy.tech/badge/cratedb-toolkit/month
[badge-license]: https://img.shields.io/github/license/crate/cratedb-toolkit.svg
[badge-package-version]: https://img.shields.io/pypi/v/cratedb-toolkit.svg
[badge-python-versions]: https://img.shields.io/pypi/pyversions/cratedb-toolkit.svg
[badge-status]: https://img.shields.io/pypi/status/cratedb-toolkit.svg
[badge-tests]: https://github.com/crate/cratedb-toolkit/actions/workflows/main.yml/badge.svg
[project-codecov]: https://codecov.io/gh/crate/cratedb-toolkit
[project-documentation]: https://cratedb-toolkit.readthedocs.io/
[project-downloads]: https://pepy.tech/project/cratedb-toolkit/
[project-license]: https://github.com/crate/cratedb-toolkit/blob/main/LICENSE
[project-pypi]: https://pypi.org/project/cratedb-toolkit
[project-tests]: https://github.com/crate/cratedb-toolkit/actions/workflows/main.yml
